#[non_exhaustive]
pub enum Request { Destroy, SetAcquirePoint { timeline: WpLinuxDrmSyncobjTimelineV1, point_hi: u32, point_lo: u32, }, SetReleasePoint { timeline: WpLinuxDrmSyncobjTimelineV1, point_hi: u32, point_lo: u32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the surface synchronization object

Destroy this surface synchronization object.

Any timeline point set by this object with set_acquire_point or set_release_point since the last commit may be discarded by the compositor. Any timeline point set by this object before the last commit will not be affected.

This is a destructor, once received this object cannot be used any longer.



SetAcquirePoint

set the acquire timeline point

Set the timeline point that must be signalled before the compositor may sample from the buffer attached with wl_surface.attach.

The 64-bit unsigned value combined from point_hi and point_lo is the point value.

The acquire point is double-buffered state, and will be applied on the next wl_surface.commit request for the associated surface. Thus, it applies only to the buffer that is attached to the surface at commit time.

If an acquire point has already been attached during the same commit cycle, the new point replaces the old one.

If the associated wl_surface was destroyed, a no_surface error is raised.

If at surface commit time there is a pending acquire timeline point set but no pending buffer attached, a no_buffer error is raised. If at surface commit time there is a pending buffer attached but no pending acquire timeline point set, the no_acquire_point protocol error is raised.

Fields

point_hi: u32

high 32 bits of the point value

point_lo: u32

low 32 bits of the point value



SetReleasePoint

set the release timeline point

Set the timeline point that must be signalled by the compositor when it has finished its usage of the buffer attached with wl_surface.attach for the relevant commit.

Once the timeline point is signaled, and assuming the associated buffer is not pending release from other wl_surface.commit requests, no additional explicit or implicit synchronization with the compositor is required to safely re-use the buffer.

Note that clients cannot rely on the release point being always signaled after the acquire point: compositors may release buffers without ever reading from them. In addition, the compositor may use different presentation paths for different commits, which may have different release behavior. As a result, the compositor may signal the release points in a different order than the client committed them.

Because signaling a timeline point also signals every previous point, it is generally not safe to use the same timeline object for the release points of multiple buffers. The out-of-order signaling described above may lead to a release point being signaled before the compositor has finished reading. To avoid this, it is strongly recommended that each buffer should use a separate timeline for its release points.

The 64-bit unsigned value combined from point_hi and point_lo is the point value.

The release point is double-buffered state, and will be applied on the next wl_surface.commit request for the associated surface. Thus, it applies only to the buffer that is attached to the surface at commit time.

If a release point has already been attached during the same commit cycle, the new point replaces the old one.

If the associated wl_surface was destroyed, a no_surface error is raised.

If at surface commit time there is a pending release timeline point set but no pending buffer attached, a no_buffer error is raised. If at surface commit time there is a pending buffer attached but no pending release timeline point set, the no_release_point protocol error is raised.

Fields

point_hi: u32

high 32 bits of the point value

point_lo: u32

low 32 bits of the point value

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message