Struct WpLinuxDrmSyncobjSurfaceV1
pub struct WpLinuxDrmSyncobjSurfaceV1 { /* private fields */ }wayland and Linux only.Expand description
per-surface explicit synchronization
This object is an add-on interface for wl_surface to enable explicit synchronization.
Each surface can be associated with only one object of this interface at any time.
Explicit synchronization is guaranteed to be supported for buffers created with any version of the linux-dmabuf protocol. Compositors are free to support explicit synchronization for additional buffer types. If at surface commit time the attached buffer does not support explicit synchronization, an unsupported_buffer error is raised.
As long as the wp_linux_drm_syncobj_surface_v1 object is alive, the compositor may ignore implicit synchronization for buffers attached and committed to the wl_surface. The delivery of wl_buffer.release events for buffers attached to the surface becomes undefined.
Clients must set both acquire and release points if and only if a non-null buffer is attached in the same surface commit. See the no_buffer, no_acquire_point and no_release_point protocol errors.
If at surface commit time the acquire and release DRM syncobj timelines are identical, the acquire point value must be strictly less than the release point value, or else the conflicting_points protocol error is raised.
See also the Request enum for this interface.